#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['robot_descriptions']

package_data = \
{'': ['*']}

install_requires = \
['GitPython >=3.1.18', 'tqdm >=4.64.0']

extras_require = \
{'cli': ['yourdfpy >=0.0.52']}

entry_points = \
{'console_scripts': ['robot_descriptions = '
                     'robot_descriptions._command_line:main']}

setup(name='robot_descriptions',
      version='0.1.0',
      description='Import open source robot description as Python modules.',
      author=None,
      author_email='Stéphane Caron <stephane.caron@normalesup.org>',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
